
library("scales")
library("ggplot2")
library("dplyr")
library("lubridate")
library("tidyr")
library("plyr")
library("zoo")
show_col(hue_pal()(2))
#library(easyGgplot2)
library(reshape2)
library(plotly)
library("reshape2", lib.loc="~/R/win-library/3.4")
#install.packages("tidyverse")

#Mac
#setwd("~/Google Drive/Skole/Master/VPS data")
#PC
setwd("C:/Users/Daniel/Google Drive/Skole/Master/data")

# ================================================== VPS Fuel Data ==================================================

Sing <- read.csv(file="HFO380_SGSIN.csv", header=TRUE, sep=",", stringsAsFactors = F)
HK   <- read.csv(file="HFO380_HKHKG.csv",  header=TRUE, sep=",", stringsAsFactors = F)

Sing$Date <- as.Date(Sing$Date, format = "%Y-%m-%d")
HK$Date   <- as.Date(HK$Date,   format = "%Y-%m-%d")

#time ordering
Sing <- Sing[order(Sing$Date),]
HK   <- HK[order(HK$Date),]

#removal of na lines
index <- which(is.na(Sing$BK_SAMPLENO)); if(length(index)>0) Sing <- Sing[-index,]
index <- which(is.na(HK$BK_SAMPLENO));   if(length(index)>0) HK   <- HK[  -index,]

#Remove > and <
index <- which(substr(Sing$density,1,1) == "<" | substr(Sing$density,1,1) == ">" )
Sing <- Sing[-index,]
Sing$density <- as.numeric(Sing$density)


index <- which(substr(HK$density,1,1) == "<" | substr(HK$density,1,1) == ">" )
HK <- HK[-index,]
HK$density <- as.numeric(HK$density)


# ================================================== VPS data prep ==================================================
#Sing$density_txt <- as.character(Sing$density_txt)
#index_bigger <-grep('>',Sing$density_txt)
#print(paste('fraction of > samples: (',length(index_bigger),'):',length(index_bigger)/nrow(Sing)))
#index_smaller <-grep('<',Sing$density_txt)
#print(paste('fraction of < samples: (',length(index_smaller),'):',length(index_smaller)/nrow(Sing)))
#index_blank <- which(is.na(Sing$REPORT_SHORT_LIFT_BENCHMARK))
#index_blank <- which(is.na(Sing$REPORT_MAX_SHORT_BENCHMARK))
# ================================================== Price data ==================================================
ifo380_price<-read.csv("price_ifo380.csv", sep = ";") 
ifo380_price$Date_hk <-   as.Date(ifo380_price$Date_hk,   format = "%d.%m.%Y")
ifo380_price$Date_sing <- as.Date(ifo380_price$Date_sing, format = "%d.%m.%Y")
ifo380_price$Date_w <-    as.Date(ifo380_price$Date_w   , format = "%d.%m.%Y")
ifo380_price$Date_mgosing <-    as.Date(ifo380_price$Date_mgosing   , format = "%d.%m.%Y")


# ================================================== End of data formatting and cleaning ===========================================================

# =================================================== PROPORTION OF lowres DATa ===================================================
index <- which(substr(Sing$density,1,1) == "<")
densitylimit <- data.frame(density = Sing$density[index] , Date = Sing$Date[index], Type = "Lower") 
index <- which(substr(Sing$density,1,1) == ">")
y <- data.frame(density = Sing$density[index] , Date = Sing$Date[index], Type = "Upper") 
densitylimit <- rbind(densitylimit, y)
densitylimit$Month <- as.Date(cut(densitylimit$Date, breaks = "month"))

#pre14<-c(31,30,31,30,31,31,30,31,30,31)
#mid <- rep(c(31,30,31,30,31,30,31,31,30,31,30,31),4)
#post17<-c(31,32)

index <- which(substr(Sing$density,1,1) != "<")
denslist <- data.frame(density = Sing$density[index] , Date = Sing$Date[index], Type = "Mid") 
index <- which(substr(denslist$density,1,1) == ">"); if(length(index)>0) denslist <- denslist[-index,]

month_range <- unique(substr(denslist$Date,1,7)) # monthly
Dens_monthly <- data.frame(month = month_range)
Dens_monthly <- na.omit(Dens_monthly)

for (i in 1:nrow(Dens_monthly)) {
  index  = which(substr(denslist$Date,1,7)     == Dens_monthly$month[i])
  index2 = which(substr(densitylimit$Date,1,7) == Dens_monthly$month[i]) 
  Dens_monthly$Fraction[i] = length(index2)/length(index)
}

Dens_monthly$month <- as.Date(paste0(Dens_monthly$month, "-01", collapse = NULL))


p2 <- ggplot(Dens_monthly, aes(x=month, y=Fraction)) +
  geom_line() + scale_y_continuous(labels = scales::percent_format(accuracy = 1)) + labs(x= element_blank(), y="% of total monthly samples")


p <- ggplot(densitylimit, aes(x=Month, color = Type, fill = Type)) + 
  geom_histogram(breaks = seq(as.Date("2013/1/1"), as.Date("2018/3/1"), by = "month"),
                 alpha = 0.5, position = "identity" ) + labs(x= element_blank(), y="Count") + theme(legend.position = c(0.95,0.79))

multiplot(p,p2)

#=================================================================================================================

# ================================================== Start of Price plots  ===========================================================
plot_price <- function(ifo380_price){
  
  hk_price    <- data.frame(date=ifo380_price$Date_hk,         price_hk=ifo380_price$Price_hk) 
  sing_price  <- data.frame(date=ifo380_price$Date_sing,       price_s=ifo380_price$Price_sing)
  w_price     <- data.frame(date=ifo380_price$Date_w,          price_w=ifo380_price$Price_w)
  mgo_price   <- data.frame(date=ifo380_price$Date_mgosing,    price_mgo=ifo380_price$Price_mgosing)
  #removal of na lines
  index <- which(is.na(sing_price$price_s)); if(length(index)>0) sing_price <- sing_price[-index,]
  index <- which(is.na(hk_price$price_hk));   if(length(index)>0)   hk_price <-   hk_price[-index,]
  index <- which(is.na(w_price$price_w));   if(length(index)>0)     w_price <-   w_price[-index,]
  
  #time ordering
  hk_price    <- hk_price[order(hk_price$date),]
  sing_price  <- sing_price[order(sing_price$date),]
  w_price     <- w_price[order(w_price$date),]
  mgo_price     <- mgo_price[order(mgo_price$date),]
  
  price <- merge(hk_price, sing_price, by="date",all=F)
  price <- merge(price, w_price, by = "date", all = F)
  #price2 <- merge(hk_price, sing_price, by="date",all=T)
  price$hk_delta <- price$price_hk - price$price_s
  price$w_delta  <- price$price_w  - price$price_s
   
  

  index <- which(price$date>='2013-01-01' & price$date <='2014-12-31') 
  preMFM  <- mean(price$deltaprice[index])
  
  
  index <- which(price$date>='2017-01-01')   # & Sing.deltadens$date<='2014-12-31') 
  postMFM <- mean(price$deltaprice[index])
  

  
  

  # ============================================================= Definition of Multiplot 
  multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
    require(grid)
    
    # Make a list from the ... arguments and plotlist
    plots <- c(list(...), plotlist)
    
    numPlots = length(plots)
    
    # If layout is NULL, then use 'cols' to determine layout
    if (is.null(layout)) {
      # Make the panel
      # ncol: Number of columns of plots
      # nrow: Number of rows needed, calculated from # of cols
      layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                       ncol = cols, nrow = ceiling(numPlots/cols))
    }
    
    if (numPlots==1) {
      print(plots[[1]])
      
    } else {
      # Set up the page
      grid.newpage()
      pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
      
      # Make each plot, in the correct location
      for (i in 1:numPlots) {
        # Get the i,j matrix positions of the regions that contain this subplot
        matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
        
        print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                        layout.pos.col = matchidx$col))
      }
    }
  } #=========================== DEF OF MULTIPLOT END ===================
  
  p2 <- ggplot(price, aes(x=date, y = hk_delta)) + 
    geom_rect(aes(xmin = as.Date("2016-01-01", format = "%Y-%m-%d"), xmax = as.Date("2017-01-01", format = "%Y-%m-%d") , ymin = -Inf, ymax = Inf), fill = "grey", alpha = 0.02) +
    geom_line( aes(col = "HK - Sing")) + labs(x= "Year", y="Price difference [USD/mt]") +
    geom_line(aes(y=w_delta, col = "World - Sing")) + 
        #geom_line( data=Rolling,  aes(y=RMean ,x=Date, col = "Rolling Mean")) +
    geom_abline(intercept = 0, slope = 0, col = "black", linetype = 2) 
    
  p2 <- p2 + scale_colour_manual(values = c("#f8766d", "#00ba38")) + theme(legend.position = c(0.87,0.9), legend.title = element_blank()) +
  p2
  
  
  
  # ================================================== Plotting price regime ==================================================
  
  trendplot <- function(price){
  
  i_const     <-    which(price$date>='2013-04-15' & price$date<='2014-08-01')
  i_decrease  <-    which(price$date>='2014-08-15' & price$date<='2016-02-01')
  i_increase  <-    which(price$date>='2016-02-01')
  
  z<-lm(price$hk_delta[i_decrease] ~ price$date[i_decrease]);summary(z)
  z<-lm(price$hk_delta[i_const] ~ price$date[i_const]);summary(z)
  z<-lm(price$hk_delta[i_increase] ~ price$date[i_increase]);summary(z)
  
  z<-lm(price$w_delta[i_decrease] ~ price$date[i_decrease]);summary(z)
  z<-lm(price$w_delta[i_const] ~ price$date[i_const]);summary(z)
  z<-lm(price$w_delta[i_increase] ~ price$date[i_increase]);summary(z)
  

  p1 <- ggplot(price[i_const,], aes(x=date, y = price_s)) +
    geom_line(col = "blue") + labs(x= "Year", y="Price [USD/mt]")  + ggtitle("Flat Trend in Singapore Price") +
    theme(plot.title = element_text(size=10, face="bold")) 

  
  p2  <- ggplot(price[i_const,], aes(x=date, y = hk_delta)) + 
    geom_line(col = "black") + labs(x= "Year", y="Price diff. [USD/mt]") +
    geom_abline(intercept = 0, slope = 0, col = "black", linetype = 2) +
    geom_smooth(method="lm", se = F, linetype = 2, col = "red") 
  #scale_colour_manual(values = c("black")) 
  #+ theme(legend.position = c(0.87,0.9), legend.title = element_blank())
  
  p3 <- ggplot(price[i_decrease,], aes(x=date, y = price_s)) + 
    geom_line(col = "blue") + labs(x= "Year", y="Price [USD/mt]")  +ggtitle("Downtrend in Singapore Price") +
    theme(plot.title = element_text(size=10, face="bold")) 
  
  p4  <- ggplot(price[i_decrease,], aes(x=date, y = hk_delta)) + 
    geom_line(col = "black") + labs(x= "Year", y="Price diff. [USD/mt]") +
    geom_abline(intercept = 0, slope = 0, col = "black", linetype = 2) +
    geom_smooth(method="lm", se = F, linetype = 2, col = "red") 
  #scale_colour_manual(values = c("black")) 
  #+ theme(legend.position = c(0.87,0.9), legend.title = element_blank())
  
  p5 <- ggplot(price[i_increase,], aes(x=date, y = price_s)) + 
    geom_line(col = "blue") + labs(x= "Year", y="Price [USD/mt]") + ggtitle("Uptrend in Singapore Price") +
    theme(plot.title = element_text(size=10, face = "bold")) 
  
  p6  <- ggplot(price[i_increase,], aes(x=date, y = hk_delta)) + 
    geom_line(col = "black") + labs(x= "Year", y="Price diff. [USD/mt]") +
    geom_abline(intercept = 0, slope = 0, col = "black", linetype = 2) +
    geom_smooth(method="lm", se = F, linetype = 2, col = "red") 
  #scale_colour_manual(values = c("black")) 
  #+ theme(legend.position = c(0.87,0.9), legend.title = element_blank())
  
  multiplot(p1, p3, p5, p2, p4, p6, cols=2)
  }
  
  # ======================= Plotting post mfm
  
  i_postmfm  <- which(price$date>='2017-01-01')
  
  
  p1 <- ggplot(price[i_postmfm,], aes(x=date, y = price_s)) + geom_line(aes(y=price_hk, col = "Hong Kong"))+ 
    geom_line(aes(col = "Singapore")) + labs(x= "Year", y="Price [USD/mt]") +ggtitle("Post 2016 Price Levels") +
    theme(plot.title = element_text(size=10, face="bold")) +
    scale_colour_manual(values = c("#00ba38", "blue")) + theme(legend.position = c(0.87,0.1), legend.title = element_blank()) 
  
  
  p2  <- ggplot(price[i_postmfm,], aes(x=date, y = hk_delta)) + 
    geom_line(col = "black") + labs(x= "Year", y="Price gap [USD/mt]") +
    geom_abline(intercept = 0, slope = 0, col = "black", linetype = 2) +
    geom_smooth(method="lm", se = F, linetype = 2, col = "red") 
  
  multiplot(p1,p2,1)
  
  
 p3 <- ggplot(price[i_postmfm,], aes(x=date, y = price_s)) + geom_line(aes(y=price_w, col = "World"))+ 
    geom_line(aes(col = "Singapore")) + labs(x= "Year", y="Price [USD/mt]") +ggtitle("Post 2016 Price Levels") +
    theme(plot.title = element_text(size=10, face="bold")) +
    scale_colour_manual(values = c("#00ba38", "blue")) + theme(legend.position = c(0.87,0.1), legend.title = element_blank()) 
  
  
  p4  <- ggplot(price[i_postmfm,], aes(x=date, y = w_delta)) + 
    geom_line(col = "black") + labs(x= "Year", y="Price gap [USD/mt]") +
    geom_abline(intercept = 0, slope = 0, col = "black", linetype = 2) +
    geom_smooth(method="lm", se = F, linetype = 2, col = "red") 
  
  multiplot(p3,p4,1)
  
  
  # ======================= end of Plotting post mfm 
  
  
  #====== plotting trend

  
  p1 <- ggplot(price, aes(x=price$date, y=price$price_s)) + 
    geom_rect(aes(xmin = as.Date("2016-01-01", format = "%Y-%m-%d"), xmax = as.Date("2017-01-01", format = "%Y-%m-%d") , ymin = -Inf, ymax = Inf), fill = "grey", alpha = 0.02) + 
    
    geom_line( aes(col = "Singapore")) + 
    geom_line(aes(y=price_hk, col = "Hong Kong")) + 
    geom_line(aes(y=price_w, col = "World")) + 
    theme(axis.title.x=element_blank()) +
    ggtitle("Bunker Price Indices")
  #labs(title = "Bunker price in Hong Kong and Singapore and Price Difference")
  p1 <- p1 + scale_colour_manual(values = c("#f8766d", "#619cff", "#00ba38")) + theme(legend.position = c(0.87,0.9), legend.title = element_blank()) + labs(y="Price [USD/mt]") 
  p1
  
    multiplot(p1, p2, cols=1) #
  

  
} #Price per metric ton of IFO380 singa blue and hk
# ================================================== End of Price plots  =============================================================

# ================================================== Start of Density plots  ===========================================================

#Density Data Formatting

index <- which(substr(Sing$density,1,1) == "<")
Sing$density[index] <- "979.998"
index <- which(substr(Sing$density,1,1) == ">")
Sing$density[index] <- "993.002"

Sing$density <- as.numeric(Sing$density)


#Plot Singapore Density
plot_density <- function(Sing, HK){ 
  
  #----------------------------------------------- Monthly median density Singapore and HK -----------------------------------------------------------
  month_range <- unique(substr(Sing$Date,1,7)) # monthly
  Fuel_monthly <- data.frame(month = month_range)
  Fuel_monthly <- na.omit(Fuel_monthly)
  
  for (i in 1:nrow(Fuel_monthly)) {
    index = which(substr(Sing$Date,1,7) == Fuel_monthly$month[i])
    Fuel_monthly$median[i]      <- median(Sing$density[index], na.rm=T) 
    Fuel_monthly$mean[i]        <-   mean(Sing$density[index], na.rm=T)
    Fuel_monthly$sd[i]          <-     sd(Sing$density[index], na.rm=T)
    Fuel_monthly$mad[i]         <-    mad(Sing$density[index], na.rm=T)
    
    Fuel_monthly$nrsamples[i]   <- length(index)
    error                       <- qnorm(0.975) * Fuel_monthly$sd[i]/sqrt(Fuel_monthly$nrsamples[i])
    Fuel_monthly$upper_conf[i]  <- Fuel_monthly$mean[i] + error
    Fuel_monthly$lower_conf[i]  <- Fuel_monthly$mean[i] - error
    Fuel_monthly$densdiff[i]    <- 991 - Fuel_monthly$median[i] 
    
    #deltadens
    Fuel_monthly$mediandd[i]      <- median(Sing$deltaDensity[index], na.rm=T) 
    #Diff between densitydeviation and difference between 991 and median density
    Fuel_monthly$cheating[i]        <- Fuel_monthly$densdiff[i] - Fuel_monthly$mediandd[i]  
  }
  
  Fuel_monthly$month   <- paste(Fuel_monthly$month,"-15", sep="")
  Fuel_monthly$month   <- as.Date(Fuel_monthly$month, format = "%Y-%m-%d")
  # ================ HK ==============
  
  HK.month_range <- unique(substr(HK$Date,1,7)) # monthly
  HK.Fuel_monthly <- data.frame(month = HK.month_range)
  HK.Fuel_monthly <- na.omit(HK.Fuel_monthly)
  
  for (i in 1:nrow(HK.Fuel_monthly)) {
    index = which(substr(HK$Date,1,7) == HK.Fuel_monthly$month[i])
    HK.Fuel_monthly$median[i] <- median(HK$density[index],na.rm=T) 
  }
  
  HK.Fuel_monthly$month <- paste(HK.Fuel_monthly$month,"-15", sep="")
  HK.Fuel_monthly$month <- as.Date(HK.Fuel_monthly$month, format = "%Y-%m-%d")
  
  
  #----------------------------------------------- Daily Median Density, Singapore and HK --------------------------------------------------------------
  
  date_range <- unique(Sing$Date) # daily
  Fuel_daily <- data.frame(date=date_range)
  
  for (i in 1:nrow(Fuel_daily)) {
    index = which(Sing$Date==Fuel_daily$date[i])
    Fuel_daily$median[i] <- median(Sing$density[index],na.rm=T) 
  }
  
  # ================ HK ==============
  
  HK.date_range <- unique(HK$Date)
  HK.Fuel_daily <- data.frame(date=HK.date_range)
  
  # Hong Kong median daily density
  for (i in 1:nrow(HK.Fuel_daily)) {
    index = which(HK$Date==HK.Fuel_daily$date[i])
    HK.Fuel_daily$median[i] <- median(HK$density[index],na.rm=T) 
  }
  
  # ================================================== Weekly Median Density, Singapore and HK ==================================================
  
  Sing$week <- paste(year(Sing$Date),week(Sing$Date),sep="-")  
  
  week_range       <- na.omit(unique(Sing$week))
  Sing.Fuel_weekly <- data.frame(week=week_range,date=rep(NA,length(week_range)),stringsAsFactors = F)
  
  Sing.Fuel_weekly$p <- NA
  Sing.Fuel_weekly$n <- NA
  for (i in 1:nrow(Sing.Fuel_weekly)){
    index                         <- which(Sing$week==Sing.Fuel_weekly$week[i])
    Sing.Fuel_weekly$median[i]    <- median(Sing$density[index], na.rm=T)
    Sing.Fuel_weekly$mean[i]      <- mean(Sing$density[index], na.rm=T)
    Sing.Fuel_weekly$sd[i]        <- sd(Sing$density[index], na.rm=T)
    Sing.Fuel_weekly$date[i]      <- Sing$Date[index[1]] # skal vre 1-tall
    Sing.Fuel_weekly$mad[i]       <- mad(Sing$density[index], na.rm=T)
    
    
    #Finne ensiding median deviation
    
    #m<-median(Sing$density[index],na.rm=T)
    m <- Sing.Fuel_weekly$median[i]
    p <- Sing$density[index]-m
    p <- p[p>0]
    Sing.Fuel_weekly$p[i] <- m + median(p,na.rm=T)
    n <- Sing$density[index] - m
    n <- n[n<0]
    Sing.Fuel_weekly$n[i] <- m + median(n,na.rm=T)
    
    #Differnece from ISO limit
    Sing.Fuel_weekly$densdiff[i]    <- 991 - Sing.Fuel_weekly$median[i] 
    
    #deltadens
    Sing.Fuel_weekly$mediandd[i]      <- median(Sing$deltaDensity[index], na.rm=T)
    m_dd <- Sing.Fuel_weekly$mediandd[i]
    p_dd <- Sing$deltaDensity[index]-m_dd
    p_dd <- p_dd[p_dd>0]
    Sing.Fuel_weekly$p_dd[i] <- m_dd + median(p_dd,na.rm=T)
    n_dd <- Sing$deltaDensity[index] - m_dd
    n_dd <- n_dd[n_dd<0]
    Sing.Fuel_weekly$n_dd[i] <- m_dd + median(n_dd,na.rm=T)
    
    
    
    
    
    
    #Diff between densitydeviation and difference between 991 and median density
    Sing.Fuel_weekly$cheating[i]        <- Sing.Fuel_weekly$densdiff[i] - Sing.Fuel_weekly$mediandd[i]
    Sing.Fuel_weekly$overstrate[i]        <- Sing.Fuel_weekly$mediandd[i]/Sing.Fuel_weekly$densdiff[i] * 100
    
    # 95 % Confidence
    #Sing.Fuel_weekly$nrsamples[i] <- length(index)
    #error                         <- qnorm(0.975) * Sing.Fuel_weekly$sd[i]/sqrt(Sing.Fuel_weekly$nrsamples[i])
    #Sing.Fuel_weekly$upper_conf[i]<-  Sing.Fuel_weekly$mean[i] + error
    #Sing.Fuel_weekly$lower_conf[i]<-  Sing.Fuel_weekly$mean[i] - error #evt median
  }
  
  Sing.Fuel_weekly$dd_spread <- Sing.Fuel_weekly$p_dd - Sing.Fuel_weekly$n_dd
  Sing.Fuel_weekly$date <- as.Date(Sing.Fuel_weekly$date,origin = "1970-01-01",tz="UTC")
  
 

  
  
# =================================================== FACET PLOT FOR RESOLUTION================
merge_density <- function(Fuel_daily, Sing.Fuel_weekly, Fuel_monthly){
  daily   <- data.frame(date=Fuel_daily$date,      Daily   = Fuel_daily$median)
  weekly  <- data.frame(date=Sing.Fuel_weekly$date, Weekly = Sing.Fuel_weekly$median)
  monthly <- data.frame(date=Fuel_monthly$month, Monthly = Fuel_monthly$median)
  
  dens <- merge(daily, weekly,      by = "date", all = T)
  dens <- merge(dens, monthly, by = "date", all = T)
  
  #convert to long datatable
  long_dens <- dens %>% gather(Resolution, Density, 2:4)
  #removing empty rows
  index <- which(is.na(long_dens$Density));   if(length(index)>0) long_dens   <- long_dens[  -index,]
  long_dens$Res_f <- factor(long_dens$Resolution, levels = c("Daily", "Weekly", "Monthly"))
  
  
  #Plotting faceted plot
  dens_plot <- ggplot(long_dens, aes(x=date, y = Density) ) + geom_line()
  dens_plot + facet_grid(rows = vars(Res_f) ) + labs(x= "Year", y = "Density [kg/m3]")
  
}


}
#============================================================ DENSITY PLOTS ========================================================================================== 
sing_price  <- data.frame(date=ifo380_price$Date_sing, price=ifo380_price$Price_sing)

#Plot Daily Density
ggplot(data=Fuel_daily, aes(x=date, y=median, group=1, colour = "red")) +
  geom_line() + geom_line(data=HK.Fuel_daily, aes(y=median, colour = "blue")) +
  ylab(label="Daily median density") + xlab("Date")

# Plot weekly density
week_dens <- ggplot(data=Sing.Fuel_weekly, aes ( x= date, y = median)) + geom_line()+ ylab(label="Density [kg/m3]") + xlab("Year")
week_dens + geom_hline(yintercept=991, col = "red") + geom_line(aes(y=n), colour="blue", linetype=2) + geom_line(aes(y=p), colour="blue", linetype=2) + labs(title = "Median Bunker Density, 1st and 3rd Quartiles in blue") 

#Plot Monthly Density
ggplot(data=Fuel_monthly, aes(x=month, y=median)) + geom_line() +
  ylab(label="Density") + xlab("Date") + labs(title = "Monthly sample median in Singapore") 
# + geom_line(data=HK.Fuel_monthly, aes(y=median), colour = "blue") 
# +  geom_ribbon(data=Fuel_monthly, aes(ymin=lower_conf, ymax=upper_conf), alpha=0.3)

#Plot density diff - dens and max dens
ggplot(data=Fuel_monthly, aes(x=month, y=densdiff)) + geom_line() +
  ylab(label="Density [kg/m3]") + xlab("Year") + geom_line(data=Fuel_monthly, aes(y=mediandd), col = "blue") + geom_line(data=Fuel_monthly, aes(y=cheating), col = "red" )


# SCATTER PLOT, stated vs tested
ggplot(data = Sing, aes(x=density, y=BDRdensity) ) + geom_abline(intercept = 0, slope = 1, col = "blue" , size = 1, linetype = 2) + 
  geom_point(size = 1, alpha = 0.5)+ xlim(c(980,992)) + ylim(c(980,992)) +
  geom_hline(yintercept=991, col = "red", linetype = 2) + geom_vline(xintercept=991, col ="red", linetype = 2) + 
  labs(x = "Tested Density [kg/m3]", y = "Stated Density [kg/m3] ") 



# =================================================== Plot delta density and distribution for delta density data presentation ===================
p <- ggplot(data=Sing.Fuel_weekly, aes(x=date)) + geom_line(aes(y=mediandd, color ="Weekly Median of Delta Density")) 
p <- p + geom_line(aes(y = p_dd, color = "3rd Quartile"), linetype = 2)
p <- p + geom_line(aes(y = n_dd, color = "1st Quartile"), linetype = 2)
p <- p + geom_line(aes(y = densdiff, color = "Deviation from ISO limit"))
# Modyfing colors and themes options
p <- p + scale_colour_manual(values = c("grey60", "grey60","red", "black")) + scale_linetype_manual(values = c(rep("dashed",4)))
p <- p + labs(y = "Delta density [kg/m3]",
              x = "Year")
p <- p + theme(legend.position = c(0.8,0.9), legend.title = element_blank())
p

p + geom_line(aes(y = dd_spread)) + geom_line(aes(y=densdiff, col ="blue"))

scale_color_manual(values = c("red", "dodgerblue3", "red", "dodgerblue3")) + 
  scale_linetype_manual(values = c(1, 1, 2, 2))




#plot cheating / utilisation
p <- ggplot(data=Sing.Fuel_weekly, aes(x=date)) + geom_line(aes(y=densdiff, color ="Difference from ISO limit"))


# adding the relative humidity data, transformed to match roughly the range of the temperature
p <- p + geom_line(aes(y= overstrate*(3.5/100), color = "Overstating Rate"), linetype=2)
p <- p + geom_line(aes(y= mediandd, color = "Median Delta Density"))

# now adding the secondary axis
p <- p + scale_y_continuous(sec.axis = sec_axis(~./3.5*100, name = "Overstating Rate [%]"))

# Modifying colours and themes options
p <- p + scale_colour_manual(values = c("blue", "black", "red"))
p <- p + labs(y = "Density [kg/m3]",
              x = "Year",
              colour = "Graphs"
              )
p <- p + theme(legend.position = c(0.8,0.9))
  p
  
  ylab(label="Density [kg/m3]") + xlab("Year") + geom_line(data=Sing.Fuel_weekly, aes(y=mediandd), col = "blue") + 
  #geom_line(data=Sing.Fuel_weekly, aes(y=cheating), col = "red" ) +
  geom_line(data=Sing.Fuel_weekly, aes(y=overstrate), col = "red")






# ================================================== End of density plots  ===========================================================

#geom_ribbon(data=predframe,aes(ymin=lwr,ymax=upr),alpha=0.3))   Standardvarians?

# ================================================== Histogram plots  ===========================================================
plot_hist <- function(Sing){
  
  Sing.deltadens <- data.frame(date = Sing$Date, dd = Sing$deltaDensity) 
  
  #removal of na lines
  index <- which(is.na(Sing.deltadens$dd)); if(length(index)>0) Sing.deltadens <- Sing.deltadens[-index,]
  
  #Time window 2013-2015
  index <- which(Sing.deltadens$date>='2013-01-01' & Sing.deltadens$date<='2014-12-31')
  h1 <- data.frame(date=Sing.deltadens$date[index], Period1 =  Sing.deltadens$dd[index])
  
  #Time window 2015-2016
  index <- which(Sing.deltadens$date>='2015-01-01' & Sing.deltadens$date<='2015-12-31')
  h2 <- data.frame(date=Sing.deltadens$date[index], Period2 =  Sing.deltadens$dd[index])
  
  #Time window 2016-2017
  index <- which(Sing.deltadens$date>='2016-01-01' & Sing.deltadens$date<='2016-12-31')
  h3 <- data.frame(date=Sing.deltadens$date[index], Period3 =  Sing.deltadens$dd[index])
  
  #Time window 2017-2019
  index <- which(Sing.deltadens$date>='2017-01-01' & Sing.deltadens$date<='2018-12-31')
  h4 <- data.frame(date=Sing.deltadens$date[index], Period4 =  Sing.deltadens$dd[index])
  
  
  #13-15
  ggplot(data=h1, aes(x=h1$dd)) +
    geom_histogram(breaks = seq(-3.5,4, by = 0.5),
                   col = "red",
                   fill= "blue",
                   alpha = .2,
                   aes(y=..count../sum(..count..))) + 
    labs(title="Histogram for Delta Density", x="Delta Density", y="Fraction") +  
    xlim(c(-4,4)) 
  
  #15-16     
  ggplot(data=h2, aes(x=h2$dd)) +
    geom_histogram(breaks = seq(-3,10, by = 0.5),
                   col = "red",
                   fill= "blue",
                   alpha = .2,
                   aes(y=..count../sum(..count..))) + 
    labs(title="Histogram for Delta Density", x="Delta Density", y="Fraction") +  
    xlim(c(-3,11)) 
  
  
  #16-17
  ggplot(data=h3, aes(x=h3$dd)) +
    geom_histogram(breaks = seq(-3.5,8, by = 0.5),
                   col = "red",
                   fill= "blue",
                   alpha = .2,
                   aes(y=..count../sum(..count..))) + 
    labs(title="Histogram for Delta Density", x="Delta Density", y="Fraction") +  
    xlim(c(-4,8))
  
  
  
  #17-18
  ggplot(data=h4, aes(x=h4$dd)) +
    geom_histogram(breaks = seq(-3.5,8, by = 0.5),
                   col = "red",
                   fill= "blue",
                   alpha = .2,
                   aes(y=..count../sum(..count..))) + 
    labs(title="Histogram for Delta Density", x="Delta Density", y="Fraction") +  
    xlim(c(-4,8))
  
  # ======= Faceted Histogram =======
  
  
  dd <- merge(h1,h2, by = "date", all = T)  
  dd <- merge(dd, h3, by = "date", all = T )
  dd <- merge(dd, h4, by = "date", all = T )
  
  #Converting to long format
  long_dd <- dd %>% gather(Period, deltadens, 2:5)
  
  #removing empty rows
  index <- which(is.na(long_dd$deltadens)); if(length(index>0)) long_dd <- long_dd[-index,]
  
  #Plotting faceted plot
  dd_plot <- ggplot(data = long_dd, aes(x=long_dd$deltadens)) +  geom_histogram(breaks = seq(-2,4, by = 0.25),
                                                                                col = "red",
                                                                                fill= "blue",
                                                                                alpha = .2,
                                                                                #aes(y=..count../sum(..count..))
  )
  dd_plot + facet_grid(rows = vars(Period)) + labs(x="Delta Density [kg/m3]", y = "Count")
  
  
  
  dens_plot <- ggplot(long_dens, aes(x=date, y = Density) ) + geom_line()
  dens_plot + facet_grid(rows = vars(Res_f) ) + labs(x= "Year", y = "Density [kg/m3]")
  
  #Thomas plot
  hist(ddens.h1$dd,breaks=seq(min(ddens.h1$dd,na.rm=T),max(ddens.h1$dd,na.rm=T)+1,1 ),xlim=c(-5,5),freq=F)
}
# ================================ Shortlift benchmark =================================================================================
plot_benchhist <- function(Sing, HK){
  
  sing_short <-  data.frame(Date = as.Date(Sing$Date) ,SL = Sing$REPORT_SHORT_LIFT_BENCHMARK, maxSL=Sing$REPORT_MAX_SHORT_BENCHMARK)
  hk_short   <-  data.frame(Date = HK$Date ,    SL = HK$REPORT_SHORT_LIFT_BENCHMARK, maxSL=HK$REPORT_MAX_SHORT_BENCHMARK)                            
  
  index <- which(is.na(sing_short$SL)); if(length(index)>0) sing_short <- sing_short[-index,]
  index <- which(is.na(hk_short$SL)); if(length(index)>0) hk_short <- hk_short[-index,]
  
  
  sing_short$week <- paste(year(sing_short$Date),week(sing_short$Date),sep="-")  
  
  week_range       <- na.omit(unique(sing_short$week))
  sing.SL <- data.frame(week=week_range,date=as.Date(rep(NA,length(week_range))),stringsAsFactors = F)
  
  sing.SL$p <- NA
  sing.SL$n <- NA
  for (i in 1:nrow(sing.SL)){
    index                         <- which(sing_short$week==sing.SL$week[i])
    sing.SL$median[i]    <- median(sing_short$SL[index], na.rm=T)
    sing.SL$mean[i]      <- mean(sing_short$SL[index], na.rm=T)
    sing.SL$sd[i]        <- sd(sing_short$SL[index], na.rm=T)
    sing.SL$date[i]      <- sing_short$Date[index[1]] # skal vre 1-tall
    sing.SL$p[i]         <- sing.SL$mean[i] + sing.SL$sd[i]
    sing.SL$n[i]         <- sing.SL$mean[i] - sing.SL$sd[i]
    
    #Finne ensiding median deviation
    
    #m<-median(Sing$density[index],na.rm=T)
    # <- sing.SL$mean[i]
    #p <- sing_short$SL[index]-m
    #p <- p[p>0]
    #sing.SL$p[i] <- m + mean(p,na.rm=T)
    #n <- sing_short$SL[index] - m
    #n <- n[n<0]
    #sing.SL$n[i] <- m + mean(n,na.rm=T)
  }
  sing.SL$BM <- "SL"
  y <- data.frame(week=week_range,date=as.Date(rep(NA,length(week_range))),stringsAsFactors = F)
  
  for (i in 1:nrow(y)){
    index                         <- which(sing_short$week==y$week[i])
    y$median[i]    <- median(sing_short$maxSL[index], na.rm=T)
    y$mean[i]      <- mean(sing_short$maxSL[index], na.rm=T)
    y$sd[i]        <- sd(sing_short$maxSL[index], na.rm=T)
    y$date[i]      <- sing_short$Date[index[1]] # skal vre 1-tall
    y$p[i]         <- y$mean[i] + y$sd[i]
    y$n[i]         <- y$mean[i] - y$sd[i]
   }
  y$BM <- "Max SL"
  
  sing.SL<-rbind(sing.SL,y)
  
  
  ggplot(data=sing.SL, aes(x=date, y = mean)) + geom_line()+ ylab(label="Benchmark Scores") + xlab("Year") +
  geom_line(aes(y=n), colour="blue", linetype=2) + geom_line(aes(y=p), colour="blue", linetype=2) + facet_grid(rows = vars(BM)) 
  
  
  
  
  
  
  
#==========================  HISTOGRAM ============================
 
  sing_short <-  data.frame(Date = Sing$Date ,sing = Sing$REPORT_SHORT_LIFT_BENCHMARK)
  hk_short   <-  data.frame(Date = HK$Date ,    hk = HK$REPORT_SHORT_LIFT_BENCHMARK) 
     
  sing_short$frac <- sing_short$sing/sum(sing_short$sing)
  hk_short$frac <- hk_short$hk/sum(hk_short$hk)
  
  

   shortlift <- sing_short
   
   
   shortlift$Port <- 'Singapore'
   names(shortlift)[2]<-'SLScore'
   x <- hk_short
   x$Port <- 'Hong Kong'
   names(x)[2]<-'SLScore'
   z <-rbind(shortlift,x)
   shortlift<-z
   
   #Alt 1
   
   ggplot(shortlift,aes(x=SLScore, stat(density))) + 
     geom_histogram(data=subset(shortlift,port == 'Singapore'), breaks = seq(0,1,by = 0.1),fill = "green", alpha = 0.2, aes(col = "Singapore")) +
     geom_histogram(data=subset(shortlift,port == 'Hong Kong'), breaks = seq(0,1,by = 0.1), fill = "blue", alpha = 0.2, aes(col = "Hong Kong")) + theme_bw() +
     scale_colour_manual(values = c("blue", "green")) +
     theme(legend.position = c(0.8,0.9), legend.title = element_blank()) 
   
   #ALT 2
   
   ggplot(shortlift,aes(x=SLScore, fill=Port,color = Port)) + 
     geom_histogram(aes(y=..density..*.1),
                    alpha=0.35, position="identity", breaks = seq(0,1,by = 0.1)) +
     theme(legend.position = c(0.9,0.95), legend.title = element_blank()) +
     labs( x="Shortlift Score", y="Fraction")
}
# ============================================================== SCATTER PLOTS =================================================================================
   
  ggplot(data = Sing, aes(x=density, y=BDRdensity)) + 
     geom_point(size=1, alpha = 0.5) + xlim(c(980,992)) + ylim(c(980,992)) 
   
  line <- data.frame(x= c(978, 991.5), y = c(13,-0.5))
  
  ggplot(data = Sing, aes(x=density, y=deltaDensity)) + xlim(c(978,991.5)) + ylim(c(-5,13))  +
 geom_line(data = line, aes(x=x,y=y), col = "red" , size = 1, linetype = 2) + geom_point(size=1, alpha = 0.5) + 
 geom_hline(yintercept=0, col = "blue", linetype = 1) + geom_vline(xintercept=991, linetype =1, col = "blue") + labs( x= "Density [kg/m3]" , y="Delta density [kg/m3]") 

  Sing$reldens <- (991-Sing$BDRdensity)/(991-Sing$density)
   
   ggplot(data=Sing, aes(x=density, y= reldens)) + ylim(c(-4,4)) +
     geom_point(size=1, alpha = 0.5) 
   
   ggplot(data = Sing, aes(x=Date, y=BDRdensity)) + 
     geom_point(size=1, alpha = 0.5)
   

plot(Sing$density,(991-Sing$BDRdensity)/(992-Sing$density))

# ============================================================== Results/Data Analysis Chapter =================================================================================

# ============================================================== DIGIT COUNT - https://en.wikipedia.org/wiki/Benford%27s_law

index <- which(Sing$Date <= '2015-12-31')
x<- Sing$BDRdensity[index]
Date <- Sing$Date[index]
x<- as.character(x)
x<- substr(x,5,5)
i <- which(x=='')
x[i]<-'0'

#data<-data.frame(  digit=as.numeric(x), date = Date, Period = rep("Before",length(x)))
#digitdata<-data.frame(  digit=seq(0,9), freq = rep(0,10), Period = rep("Before",10))

digitdata <- data.frame(digit=c(seq(0,9),seq(0,9)), freq = rep(0,20), Period = c(rep("Before MFM",10),rep("After MFM",10)))

for (i in 0:9){
  digitdata$freq[i+1] <- length(which(x == as.character(i)))/length(x)
}
 
index <- which(Sing$Date >= '2017-01-01')
x<- Sing$BDRdensity[index]
Date <- Sing$Date[index]
x<- as.character(x)
x<- substr(x,5,5)
i <- which(x=='')
x[i]<-'0'

length(which(x == as.character(0)))
length(which(x == as.character(7)))
length(which(x == as.character(8)))

for (i in 0:9){
  digitdata$freq[i+11] <- length(which(x == as.character(i)))/length(x)
}

digitdata$Period_f <- factor(digitdata$Period, levels = c("Before MFM", "After MFM"))
digitdata$pct      <- as.numeric(format(round(digitdata$freq, 3), nsmall = 2))

p1 <- ggplot(digitdata, aes(digit, freq, fill = Period_f)) + 
  geom_bar(stat = "identity", alpha = 0.8) +
  scale_x_continuous(breaks=seq(0,9,1)) + 
  #scale_y_continuous(labels = percent_format()) + 
  scale_y_continuous(labels = scales::percent_format(accuracy = 1)) +
  facet_grid(~Period_f) +
  labs( x="Decimal digit of stated density", y="Fraction") +
  geom_text(aes(y=freq,label = paste0(pct*100," %")), nudge_y = .019) +
  theme(legend.position = "none") + ggtitle("Stated bunker density") + 
  theme(plot.title = element_text( size=11, face="bold"))


#======================================== TESTED BUNKER DENSITY ============================

index <- which(Sing$Date <= '2015-12-31')
x<- Sing$density[index]
Date <- Sing$Date[index]
x<- as.character(x)
x<- substr(x,5,5)
i <- which(x=='')
x[i]<-'0'

#data<-data.frame(  digit=as.numeric(x), date = Date, Period = rep("Before",length(x)))
#digitdata<-data.frame(  digit=seq(0,9), freq = rep(0,10), Period = rep("Before",10))

digitdata <- data.frame(digit=c(seq(0,9),seq(0,9)), freq = rep(0,20), Period = c(rep("Before MFM",10),rep("After MFM",10)))

for (i in 0:9){
  digitdata$freq[i+1] <- length(which(x == as.character(i)))/length(x)
}

index <- which(Sing$Date >= '2017-01-01')
x<- Sing$density[index]
Date <- Sing$Date[index]
x<- as.character(x)
x<- substr(x,5,5)
i <- which(x=='')
x[i]<-'0'

length(which(x == as.character(0)))
length(which(x == as.character(7)))
length(which(x == as.character(8)))

for (i in 0:9){
  digitdata$freq[i+11] <- length(which(x == as.character(i)))/length(x)
}

digitdata$Period_f <- factor(digitdata$Period, levels = c("Before MFM", "After MFM"))
digitdata$pct      <- as.numeric(format(round(digitdata$freq, 3), nsmall = 2))

p2 <- ggplot(digitdata, aes(digit, freq, fill = Period_f)) + 
  geom_bar(stat = "identity", alpha = 0.8) +
  scale_x_continuous(breaks=seq(0,9,1)) + 
  #scale_y_continuous(labels = percent_format()) + 
  scale_y_continuous(labels = scales::percent_format(accuracy = 1)) +
  facet_grid(~Period_f) +
  labs( x="Decimal digit of stated density", y="Fraction") +
  geom_text(aes(y=freq,label = paste0(pct*100," %")), nudge_y = .019) +
  theme(legend.position = "none") + ggtitle("Tested bunker density")+ 
  theme(plot.title = element_text( face="bold", size=11))



# =========== LAST AND FIRST MONTH POST MFM

postmfmdigit <- data.frame(digit=c(seq(0,9),seq(0,9),seq(0,9)), freq = rep(0,30), Period = c(rep("January 2017",10), rep("August 2017",10),rep("March 2018",10)))

index <- which(Sing$Date >= '2017-01-01'& Sing$Date <= '2017-01-31')
x<- Sing$BDRdensity[index]
Date <- Sing$Date[index]
x<- as.character(x)
x<- substr(x,5,5)
i <- which(x=='')
x[i]<-'0'

for (i in 0:9){
  postmfmdigit$freq[i+1] <- length(which(x == as.character(i)))/length(x)
}

#================================ 2017 Aug
index <- which(Sing$Date >= '2017-08-01'& Sing$Date <= '2017-08-31')
x<- Sing$BDRdensity[index]
Date <- Sing$Date[index]
x<- as.character(x)
x<- substr(x,5,5)
i <- which(x=='')
x[i]<-'0'

for (i in 0:9){
  postmfmdigit$freq[i+11] <- length(which(x == as.character(i)))/length(x)
}
#================= 2017 Aug end

#================================
index <- which(Sing$Date >= '2018-03-01')
x<- Sing$BDRdensity[index]
Date <- Sing$Date[index]
x<- as.character(x)
x<- substr(x,5,5)
i <- which(x=='')
x[i]<-'0'

for (i in 0:9){
  postmfmdigit$freq[i+21] <- length(which(x == as.character(i)))/length(x)
}
#==========

postmfmdigit$Period_f <- factor(postmfmdigit$Period, levels = c("January 2017", "August 2017", "March 2018"))
postmfmdigit$pct      <- as.numeric(format(round(postmfmdigit$freq, 3), nsmall = 3))


p2 <- ggplot(postmfmdigit, aes(digit, freq)) + 
  geom_bar(stat = "identity", fill="#00bfc4", alpha = 0.8) +
  scale_x_continuous(breaks=seq(0,9,1)) + 
  #scale_y_continuous(labels = percent_format()) + 
  scale_y_continuous(labels = scales::percent_format(accuracy = 1)) +
  facet_grid(~Period_f) +
  labs( x="Decimal digit of stated density", y="Fraction") +
  geom_text(aes(y=freq,label = paste0(pct*100," %")), nudge_y = .019)

# =========== =========== =========== =========== DIGIT END

  
# FRACTION OF POSITIVE DELTA DENSITY
index <- which(is.na(Sing$deltaDensity)); if(length(index)>0) Sing <- Sing[-index,]

index <- which(Sing$Date<'2016-01-01')
pre_sing  <- Sing[index,]

index <- which(Sing$Date>='2017-01-01')
post_sing <- Sing[index,]


#Set z-value
z       <- 1.96

#PRE MFM
n       <- nrow(pre_sing) 
p_pre   <- length(  which(pre_sing$deltaDensity>0) ) / n  
sd      <- z*sqrt( p_pre*(1-p_pre) / n  )
ci_pre  <- c(p_pre-sd,p_pre+sd) 


#POST MFM
n       <- nrow(post_sing)
p_post  <- length( which(post_sing$deltaDensity>0) ) / n  
sd      <- z*sqrt( p_post*(1-p_post) / n  )
ci_post  <- c(p_pre-sd,p_pre+sd) 

 
#========================= PRICE COMPARE =====================================================


hk_price    <- data.frame(date=ifo380_price$Date_hk, price=ifo380_price$Price_hk) 
sing_price  <- data.frame(date=ifo380_price$Date_sing, price=ifo380_price$Price_sing)

#removal of na lines
index <- which(is.na(sing_price$price)); if(length(index)>0) sing_price <- sing_price[-index,]
index <- which(is.na(hk_price$price));   if(length(index)>0)   hk_price <-   hk_price[-index,]

#time ordering
hk_price    <- hk_price[order(hk_price$date),]
sing_price  <- sing_price[order(sing_price$date),]

price <- merge(hk_price, sing_price, by="date",all=F)
#price2 <- merge(hk_price, sing_price, by="date",all=T)
price$deltaprice <- price$price.x - price$price.y

index  <- which(price$date >= "2014-06-15" & price$date < "2016-01-01")
index2 <- which(price$date >= "2016-01-01")

price1 <- price[index,]
price2 <- price[index2,]

#MULTIPLE LIN REG https://stackoverflow.com/questions/15633714/adding-a-regression-line-on-a-ggplot

p1 <- ggplot(price1,  aes(x=date, y = deltaprice)) + 
  geom_line( aes(col = "Price difference")) + labs(x= "Year", y="Price difference [USD/mt]") +
  geom_abline(intercept = 0, slope = 0, col = "red") +
  scale_colour_manual(values = c("Black", "Red", "Blue")) + theme(legend.position = c(0.87,0.9), legend.title = element_blank())

ggplot(price1,aes(date,deltaprice))+stat_summary(fun.data=mean_cl_normal) + 
  geom_smooth(method='lm') + 
  geom_line()

p2 <- ggplot(price2,  aes(x=date, y = deltaprice)) + 
  geom_line( aes(col = "Price difference")) + labs(x= "Year", y="Price difference [USD/mt]") +
  geom_abline(intercept = 0, slope = 0, col = "red") +
  scale_colour_manual(values = c("Black", "Red", "Blue")) + theme(legend.position = c(0.87,0.9), legend.title = element_blank())

ggplot(price2[ind,],aes(date,deltaprice))+stat_summary(fun.data=mean_cl_normal) + 
  geom_smooth(method='lm') + 
  geom_line() + labs(x="Time", y = "Price difference [USD/mt]")

#=========== Scatter Plot

pa <- ggplot(data = price1, aes(x=price.y, y=price.x) ) + geom_abline(intercept = 0, slope = 1, col = "blue" , size = 1, linetype = 2) + 
  geom_point(size = 1, alpha = 0.5)+ 
  labs(x = "Singapore [USD]", y = "Hong Kong [USD]") 

pb <- ggplot(data = pricelag1, aes(x=price.y, y=price.x) ) + geom_abline(intercept = 0, slope = 1, col = "blue" , size = 1, linetype = 2) + 
  geom_point(size = 1, alpha = 0.5)+ 
  labs(x = "Singapore [USD]", y = "Hong Kong [USD]") 

pc <- ggplot(data = price2, aes(x=price.y, y=price.x) ) + geom_abline(intercept = 0, slope = 1, col = "blue" , size = 1, linetype = 2) + 
  geom_point(size = 1, alpha = 0.5)+ 
  labs(x = "Singapore [USD]", y = "Hong Kong [USD]") 

pd <- ggplot(data = pricelag2, aes(x=price.y, y=price.x) ) + geom_abline(intercept = 0, slope = 1, col = "blue" , size = 1, linetype = 2) + 
  geom_point(size = 1, alpha = 0.5)+ 
  labs(x = "Singapore [USD]", y = "Hong Kong [USD]") 

multiplot(pa,pc,pb,pd, cols = 2)
#=========== Scatter Plot


# ============================================================ DELTA DENSITY Analysis ============================================================


n_pre   <- length(which(!is.na(Sing$deltaDensity[Sing$Date  < "2016-01-01"])))
n_post  <- length(which(!is.na(Sing$deltaDensity[Sing$Date >= "2017-01-01"])))
m_post  <- mean(Sing$deltaDensity[Sing$Date >= "2017-01-01"], na.rm = T)
m_pre   <- mean(Sing$deltaDensity[Sing$Date < "2016-01-01"], na.rm = T)
sd_pre  <- sd(Sing$deltaDensity[Sing$Date >= "2017-01-01"], na.rm = T)
sd_post <- sd(Sing$deltaDensity[Sing$Date < "2016-01-01"], na.rm = T)

# m_pre-m_post

# 1.96*sqrt(sd_pre^2/n_pre+sd_pre^2/n_post)

CI_pre <- c(    round(m_pre - 1.96*sqrt(sd_pre^2/n_pre),3)   ,  round(m_pre + 1.96*sqrt(sd_pre^2/n_pre),3)   ) 
CI_post <- c(    round(m_post - 1.96*sqrt(sd_post^2/n_post),3)   ,  round(m_post + 1.96*sqrt(sd_post^2/n_post),3)   ) 


conf_interval <- c(round(m_pre - 1.96*sqrt(sd_pre^2/n_pre+sd_pre^2/n_post),3), round(m_pre + 1.96*sqrt(sd_pre^2/n_pre+sd_pre^2/n_post),3))
conf_interval <- c(m,sort(conf_interval))

densdistr <- Sing[which(Sing$Date >= "2017-01-01"),]
densdistr$Period <- "Pre-MFM"
y         <- Sing[which(Sing$Date < "2016-01-01"),]
y$Period <- "Post-MFM"
densdistr <- rbind(densdistr,y)
densdistr <- densdistr[which(!is.na(densdistr$density)),] 


#quartile function 
quart <- function(x) {
  x <- sort(x)
  n <- length(x)
  m <- (n+1)/2
  if (floor(m) != m) {
    l <- m-1/2; u <- m+1/2
  } else {
    l <- m-1; u <- m+1
  }
  c(Q1=median(x[1:l]), Q3=median(x[u:n]))
}
median(Sing$density[which(Sing$Date >= "2017-01-01")])
qrt <- quart(Sing$density[which(Sing$Date >= "2017-01-01")])

ggplot(densdistr, aes(x=density, fill = Period)) + 
  geom_histogram( breaks = seq(986,991,.1), alpha=0.75) 
  

ggplot(plotframe, aes(densto, fill = Period)) + 
  geom_bar(stat="identity", aes(y=mean), position = posn_d, alpha=.6) + 
  theme(legend.position = c(0.9,0.9), legend.title = element_blank()) +
  labs( x="Density [kg/m3]", y="Mean of delta density [kg/m3]") +
  scale_x_continuous(breaks = seq(988, 991, by = .2)) 
#alt 2
ggplot(plotframe, aes(densto, fill = Period)) + 
  geom_bar(stat="identity", aes(y=mean), alpha=.5) + 
  theme(legend.position = c(0.9,0.9), legend.title = element_blank()) +
  labs( x="Density [kg/m3]", y="Mean of delta density [kg/m3]")



#======================================= Mean delta density, post mfm vs pre mfm ======================================= 

Fuel <- Sing

deltaDens  <- function(Fuel, densityRange =c(989.5,989.6)){
  i_post <- which(Fuel$Date >='2017-01-01' )
  i_pre  <- which(Fuel$Date < '2016-01-01' )
  d_post  <- Fuel$density[i_post]
  d_pre   <- Fuel$density[i_pre ]
  dd_post <- Fuel$deltaDensity[i_post]
  dd_pre  <- Fuel$deltaDensity[i_pre ]
  x <- data.frame(d=c(d_pre,d_post),dd=c(dd_pre,dd_post), ind=c(rep('pre',length(dd_pre)),rep('post',length(dd_post)) ))
  x <- x[order(x$d),]
  x <- x[which(!is.na(x$d)),]
  x <- x[which(!is.na(x$dd)),]
  y <- x[which(x$d> densityRange[1] & x$d<=densityRange[2]),]
  n_pre    <- length(y$dd[y$ind=='pre'])
  n_post   <- length(y$dd[y$ind=='post'])
  m_pre  <- mean(y$dd[y$ind=='pre'])
  m_post <- mean(y$dd[y$ind=='post'])
  sd_pre  <- sd(y$dd[y$ind=='pre'])
  sd_post <- sd(y$dd[y$ind=='post'])
  
  # m_pre-m_post
  # 1.96*sqrt(sd_pre^2/n_pre+sd_pre^2/n_post)
  m <- m_post-m_pre
  #conf_interval <- c(round(m + 1.96*sqrt(sd_pre^2/n_pre+sd_pre^2/n_post),3),round(m - 1.96*sqrt(sd_pre^2/n_pre+sd_pre^2/n_post),3))
  conf_interval <- c(m_pre,m_post,sd_pre,sd_post,n_pre,n_post)
  return(conf_interval)
}

dRange =c(988,991)

Fuel <- Fuel[Fuel$density > dRange[1] & Fuel$density <= dRange[2] ,]
Fuel$density <- as.numeric(Fuel$density)
Fuel$deltaDensity <- as.numeric(Fuel$deltaDensity)
result <- NULL
bin <- seq(dRange[1],dRange[2],0.1)
for (i in 1:(length(bin)-1)) result <- rbind(result, c(bin[i], bin[i+1], deltaDens(Fuel, densityRange = c(bin[i], bin[i+1])))    )
result <- data.frame(result)
names(result) <- c('densFrom','densTo','m_pre','m_post','sd_pre','sd_post','n_pre','n_post')

plotframe <- data.frame(densto = result$densTo-.05, mean = result$m_post, Period = "Post-MFM delta density")
x         <- data.frame(densto = result$densTo-.05, mean = result$m_pre , Period =  "Pre-MFM delta density")
plotframe <- rbind(plotframe,x)

posn_d <- position_dodge(0.03)

ggplot(plotframe, aes(densto, fill = Period)) + 
  geom_bar(stat="identity", aes(y=mean), position = posn_d, alpha=.6) + 
  theme(legend.position = c(0.9,0.9), legend.title = element_blank()) +
  labs( x="Density [kg/m3]", y="Mean of delta density [kg/m3]") +
  scale_x_continuous(breaks = seq(988, 991, by = .2)) 

ggplot(plotframe, aes(densto, fill = Period)) + 
  geom_bar(stat="identity", aes(y=mean), position = posn_d, alpha=.6) + 
  theme(legend.position = c(0.9,0.9), legend.title = element_blank()) +
  labs( x="Density [kg/m3]", y="Mean of delta density [kg/m3]") +
  scale_x_continuous(breaks = seq(988, 991, by = .2)) 

#alt 2 (brukes ikke)
ggplot(plotframe, aes(densto, fill = Period)) + 
  geom_bar(stat="identity", aes(y=mean), alpha=.5) + 
  theme(legend.position = c(0.9,0.9), legend.title = element_blank()) +
  labs( x="Density [kg/m3]", y="Mean of delta density [kg/m3]")


# ========================================== Density histogram, pre-MFM vs post-MFM ============================================================

#Sing
densdistr <- Sing[which(Sing$Date >= "2017-01-01"),]
densdistr$Period <- "Post-MFM"
y         <- Sing[which(Sing$Date < "2016-01-01"),]
y$Period <- "Pre-MFM"

#HK
densdistr <- HK[which(HK$Date >= "2017-01-01"),]
densdistr$Period <- "Post-MFM"
y         <- HK[which(HK$Date < "2016-01-01"),]
y$Period <- "Pre-MFM"





densdistr <- rbind(densdistr,y)
densdistr <- densdistr[which(!is.na(densdistr$density)),] 
densdistr <- densdistr[which(!is.na(densdistr$deltaDensity)),] 
index <- which(is.na(densdistr$density)); if(length(index)>0) densdistr <- densdistr[-index,]
index <- which(is.na(densdistr$deltaDensity)); if(length(index)>0) densdistr <- densdistr[-index,]

i_pre  <- which(densdistr$Date < '2016-01-01')
i_post <- which(densdistr$Date >='2017-01-01' )

#t_test data
dd_pre  <- densdistr$deltaDensity[i_pre]
dd_post <- densdistr$deltaDensity[i_post]


m_pre  <- mean(densdistr$deltaDensity[i_pre])
m_post <- mean(densdistr$deltaDensity[i_post])

md_pre  <- mean(densdistr$density[i_pre])
md_post <- mean(densdistr$density[i_post])


mean(densdistr$deltaDensity)

#delta density distribution, post-MFM vs pre-MFM

ggplot(densdistr) +  
  geom_histogram(data = densdistr[i_pre,],breaks = seq(-4,6,0.5), aes(x=deltaDensity, y = ..density..), alpha = .1, fill = "red") +
  geom_histogram(data = densdistr[i_post,],breaks = seq(-4,6,0.5), aes(x=deltaDensity, y = ..density..), alpha = .1, fill = "blue") +
  geom_density(data = densdistr[i_pre,],  col = "red",aes(x=deltaDensity, y = ..density..))+
  geom_density(data = densdistr[i_post,], col = "blue", aes( x=deltaDensity, y = ..density..)) + 
  labs(x="Delta Density [kg/m3]", y="Fraction") + 
  theme(legend.position = c(0.9,0.9), legend.title = element_blank()) +
  xlim(c(-4,6)) +geom_vline(xintercept=m_pre, col ="red", linetype=2, alpha= 0.5) + geom_vline(xintercept=m_post, col ="blue", linetype=2, alpha= 0.5) 


#Density Distribution, post-MFM vs pre-MFM

ggplot(densdistr) +  
  geom_histogram(data = densdistr[i_pre,],breaks = seq(980,992,0.5), aes(x=density, y = ..density..), alpha = .1, fill = "red") +
  geom_histogram(data = densdistr[i_post,],breaks = seq(980,992,0.5), aes(x=density, y = ..density..), alpha = .1, fill = "blue") +
  geom_density(data = densdistr[i_pre,],  col = "red",aes(x=density, y = ..density..))+
  geom_density(data = densdistr[i_post,], col = "blue", aes( x=density, y = ..density..)) + 
  labs(x="Density [kg/m3]", y="Fraction") + 
  xlim(c(980,993)) +geom_vline(xintercept=md_pre, col ="red", linetype=2, alpha= 0.5) + geom_vline(xintercept=md_post, col ="blue", linetype=2, alpha= 0.5) 



ggplot(densdistr, aes(x=density, fill = Period)) + 
  geom_histogram( breaks = seq(988,991,.1), alpha=0.75) +
  theme(legend.position = c(0.9,0.9), legend.title = element_blank()) +
  labs( x="Density [kg/m3]", y="Count") + geom_abline(intercept = 100, linetype = 2, slope = 0, col = "black") # +
  #geom_vline(xintercept = m_pre, col = "#F8766D" , linetype=2) + geom_vline(xintercept = m_post, col = "#00bfc4", linetype=2)



#==================Histogram binwise
ggplot(densdistr) +  
  geom_histogram(data = densdistr[i_pre,],breaks = seq(988,991,0.1), aes(x=density, y = ..density..), alpha = .1, fill = "red" , col = "red") +
  geom_histogram(data = densdistr[i_post,],breaks = seq(988,991,0.1), aes(x=density, y = ..density..), alpha = .1, fill = "blue") +
  #geom_density(data = densdistr[i_pre,],  col = "red",aes(x=density, y = ..density..))+
  #geom_density(data = densdistr[i_post,], col = "blue", aes( x=density, y = ..density..)) + 
  labs(x="Density [kg/m3]", y="Fraction") + 
  xlim(c(988,991))# +geom_vline(xintercept=md_pre, col ="red", linetype=2, alpha= 0.5) + geom_vline(xintercept=md_post, col ="blue", linetype=2, alpha= 0.5) 

HKhistogram<-ggplot(densdistr) +  
  geom_histogram(data = densdistr[i_pre,],breaks = seq(988,991,0.1), aes(x=density), alpha = .2, fill = "red") +
  geom_histogram(data = densdistr[i_post,],breaks = seq(988,991,0.1), aes(x=density), alpha = .4, fill = "blue", col="blue" ) +
  #geom_density(data = densdistr[i_pre,],  col = "red",aes(x=density, y = ..density..))+
  #geom_density(data = densdistr[i_post,], col = "blue", aes( x=density, y = ..density..)) + 
  labs(x="Density [kg/m3]", y="Count (Hong Kong)") + 
  xlim(c(988,991)) +geom_hline(yintercept=30, linetype=2, alpha= 0.5) #+ geom_vline(xintercept=md_post, col ="blue", linetype=2, alpha= 0.5) 

multiplot(Singhistogram, HKhistogram, cols=1)
